@@ -2,14 +2,14 @@ use crate::ProfileIdentifier;
 use ockam_core::Result;
 use serde::{Deserialize, Serialize};
 
-mod identifier_trust_policy;
-pub use identifier_trust_policy::*;
+mod trust_identifier_policy;
+pub use trust_identifier_policy::*;
 mod all_trust_policy;
 pub use all_trust_policy::*;
 mod any_trust_policy;
 pub use any_trust_policy::*;
-mod no_op_trust_policy;
-pub use no_op_trust_policy::*;
+mod trust_everyone_policy;
+pub use trust_everyone_policy::*;
 
 #[derive(Clone, Serialize, Deserialize)]
 pub struct SecureChannelTrustInfo {
