@@ -12,8 +12,12 @@ macro_rules! credential_type {
         use $crate::CredentialAttributeSchema;
         use $crate::CredentialAttributeType::{Number, Utf8String, Blob};
 
-        #[allow(unused_mut)]
-        let mut attributes = vec![];
+        let mut attributes = vec![CredentialAttributeSchema {
+            label: $crate::SECRET_ID.into(),
+            description: "".to_string(),
+            attribute_type: Blob,
+            unknown: true,
+        }]; // FIXME: Should we include SECRET_ID in this macro?
         $(attributes.push($x.into());)*
 
         $crate::CredentialSchema {
@@ -38,10 +42,25 @@ macro_rules! credential_attribute_values {
     ($($x:expr),* $(,)?) => ({
         use $crate::CredentialAttribute;
 
-        #[allow(unused_mut)]
         let mut attribute_values: Vec<CredentialAttribute> = vec![];
         $(attribute_values.push($x.into());)*
 
         attribute_values
     });
 }
+
+/// Creates a list of revealed attributes containing the arguments.
+///
+/// ```
+/// # use ockam_entity::reveal_attributes;;
+/// let reveal_attributes = reveal_attributes!["ABCD-EFGH", "BDC".to_string()];
+/// ```
+#[macro_export]
+macro_rules! reveal_attributes {
+    ($($x:expr),* $(,)?) => ({
+        let mut reveal_attributes: Vec<String> = vec![];
+        $(reveal_attributes.push($x.into());)*
+
+        reveal_attributes
+    });
+}
