@@ -31,6 +31,16 @@ pub enum EntityError {
     IdentityApiFailed,
     ContactVerificationFailed,
     InvalidProfileId,
+    DuplicateCredential,
+    CredentialNotFound,
+    InvalidIssueState,
+    CredentialTrustCheckFailed,
+    SchemaIdDoesntMatch,
+    IssuerListenerInvalidMessage,
+    HolderInvalidMessage,
+    IssuerInvalidMessage,
+    PresenterInvalidMessage,
+    VerifierInvalidMessage,
 }
 
 impl EntityError {
