@@ -26,6 +26,10 @@ use crate::{
     ProfileChangeEvent, ProfileIdentifier, ProofRequestId, SecureChannels, SigningPublicKey,
     TrustPolicy, TTL,
 };
+use ockam_core::compat::{
+    string::{String, ToString},
+    vec::Vec,
+};
 use ockam_core::{Address, Result, Route};
 use ockam_vault::{PublicKey, Secret};
 use signature_bls::SecretKey;
